@@ -79,7 +79,7 @@ class Q2Lines(Q2Form):
             # disabled="*",
             to_table="forms",
             to_column="name",
-            related="title",
+            related="name",
             # nogrid=1,
             # noform=1,
         )
